library datalandingpage_devaloop_com;

import 'dart:async';
import 'dart:math';

import 'package:flutter/material.dart';

class DataLandingPage extends StatefulWidget {
  final String dataTitle;
  final Future<int> totalData;
  final Future<List<ListTile>> top10LatestData;
  final Function()? searchClick;
  final Function()? addClick;

  const DataLandingPage({
    super.key,
    required this.dataTitle,
    required this.totalData,
    required this.top10LatestData,
    required this.searchClick,
    required this.addClick,
  });

  @override
  DataLandingPageState createState() {
    return DataLandingPageState();
  }
}

class DataLandingPageState extends State<DataLandingPage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    var appBar = AppBar(
      title: Text(widget.dataTitle),
      actions: [
        IconButton(
          icon: const Icon(Icons.search),
          tooltip: 'Search',
          onPressed: widget.searchClick,
        ),
        IconButton(
          icon: const Icon(Icons.add),
          tooltip: 'Add',
          onPressed: widget.addClick,
        ),
      ],
    );

    var statusBarHeight = MediaQuery.of(context).viewPadding.top;

    var isPotrait = MediaQuery.of(context).orientation == Orientation.portrait;
    var globalWidht = MediaQuery.of(context).size.width;
    var globalHeight = MediaQuery.of(context).size.height - statusBarHeight;

    var boxHeight = (isPotrait
        ? ((globalHeight - appBar.preferredSize.height - 10) / 2)
        : (globalHeight - appBar.preferredSize.height - 10));

    var boxWidth = isPotrait ? globalWidht : ((globalWidht / 2) - 10);

    //Top latest data
    var labelTopDataHeight = boxHeight / 8;
    var labelTopDataFontSize = labelTopDataHeight / 1.9;

    var listTopDataHeight = boxHeight - labelTopDataHeight;

    //Total data
    var globalWidthCircle = (globalHeight / 2);
    var globalHeightCircle =
        ((globalHeight - appBar.preferredSize.height - 10) / 2);
    var parentCircularSize =
        (isPotrait ? min(globalHeightCircle, globalWidthCircle) : boxHeight) /
            1.5;
    var parentCircularPercentage = parentCircularSize / 2;
    var childCircularSize = parentCircularSize / 1.2;
    var childCircularPercentage = childCircularSize / 2;
    var textCountData = childCircularSize / 4;
    var textLabelTotal = textCountData / 1.2;

    return Scaffold(
      appBar: appBar,
      body: SizedBox(
        width: globalWidht,
        height: globalHeight,
        child: Card(
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(10),
          ),
          color: Colors.white,
          margin: const EdgeInsets.only(
            left: 10,
            right: 10,
            top: 0,
            bottom: 10,
          ),
          child: Wrap(
            children: [
              SizedBox(
                width: boxWidth,
                height: boxHeight,
                child: Center(
                  child: FutureBuilder(
                    future: widget.totalData,
                    builder: (context, snapshot) {
                      if (snapshot.connectionState == ConnectionState.waiting) {
                        return const Column(
                          children: [
                            Expanded(
                              child: Align(
                                alignment: Alignment.bottomCenter,
                                child: CircularProgressIndicator(),
                              ),
                            ),
                            Expanded(
                              child: Padding(
                                padding: EdgeInsets.only(
                                  top: 15,
                                ),
                                child: Text(
                                  "Loading: Total",
                                  style: TextStyle(
                                    color: Colors.black54,
                                  ),
                                ),
                              ),
                            ),
                          ],
                        );
                      } else if (snapshot.hasError) {
                        return Text('Error: ${snapshot.error}');
                      } else {
                        final countData = snapshot.data ?? 0;

                        return ShowUp(
                          delay: 250,
                          child: Container(
                            height: parentCircularSize,
                            width: parentCircularSize,
                            decoration: BoxDecoration(
                              color: Colors.lightBlue,
                              borderRadius: BorderRadius.circular(
                                  parentCircularPercentage),
                            ),
                            child: Center(
                              child: Container(
                                height: childCircularSize,
                                width: childCircularSize,
                                decoration: BoxDecoration(
                                  color: Colors.white,
                                  borderRadius: BorderRadius.circular(
                                      childCircularPercentage),
                                ),
                                child: Center(
                                  child: SizedBox(
                                    height: childCircularSize,
                                    width: childCircularSize,
                                    child: Column(
                                      children: [
                                        SizedBox(
                                          width: childCircularSize,
                                          height: childCircularSize / 2,
                                          child: Align(
                                            alignment: Alignment.bottomCenter,
                                            child: ShowUp(
                                              delay: 750,
                                              child: Text(
                                                countData.toString(),
                                                style: TextStyle(
                                                  color: Colors.black54,
                                                  fontSize: textCountData,
                                                  fontWeight: FontWeight.bold,
                                                ),
                                              ),
                                            ),
                                          ),
                                        ),
                                        SizedBox(
                                          width: childCircularSize,
                                          height: childCircularSize / 2,
                                          child: Align(
                                            alignment: Alignment.topCenter,
                                            child: ShowUp(
                                              delay: 500,
                                              child: Text(
                                                "TOTAL",
                                                style: TextStyle(
                                                  color: Colors.black54,
                                                  fontSize: textLabelTotal,
                                                  fontWeight: FontWeight.bold,
                                                ),
                                              ),
                                            ),
                                          ),
                                        ),
                                      ],
                                    ),
                                  ),
                                ),
                              ),
                            ),
                          ),
                        );
                      }
                    },
                  ),
                ),
              ),
              SizedBox(
                width: boxWidth,
                height: boxHeight,
                child: FutureBuilder(
                  future: widget.top10LatestData,
                  builder: (context, snapshot) {
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return const Column(
                        children: [
                          Expanded(
                            child: Align(
                              alignment: Alignment.bottomCenter,
                              child: CircularProgressIndicator(),
                            ),
                          ),
                          Expanded(
                            child: Padding(
                              padding: EdgeInsets.only(
                                top: 15,
                              ),
                              child: Text(
                                "Loading: Top 10 Latest Data",
                                style: TextStyle(
                                  color: Colors.black54,
                                ),
                              ),
                            ),
                          ),
                        ],
                      );
                    } else if (snapshot.hasError) {
                      return Text('Error: ${snapshot.error}');
                    } else {
                      final data = snapshot.data ?? <ListTile>[];

                      return Column(
                        children: [
                          ShowUp(
                            delay: 250,
                            child: SizedBox(
                              height: labelTopDataHeight,
                              child: Align(
                                alignment: Alignment.bottomCenter,
                                child: Text(
                                  "TOP 10 LATEST DATA",
                                  style: TextStyle(
                                    color: Colors.black54,
                                    fontSize: labelTopDataFontSize,
                                    fontWeight: FontWeight.bold,
                                  ),
                                ),
                              ),
                            ),
                          ),
                          ShowUp(
                            delay: 500,
                            child: Container(
                              height: listTopDataHeight,
                              width: boxWidth,
                              padding: const EdgeInsets.all(15),
                              child: Container(
                                decoration: const BoxDecoration(
                                  border: Border(
                                    top: BorderSide(
                                      color: Colors.blue,
                                      width: 2,
                                    ),
                                  ),
                                ),
                                child: data.isNotEmpty
                                    ? ListView.separated(
                                        itemBuilder: (context, index) {
                                          return data[index];
                                        },
                                        separatorBuilder: (context, index) =>
                                            const Divider(),
                                        itemCount: data.length,
                                        shrinkWrap: true,
                                      )
                                    : const Center(
                                        child: Text(
                                          "No data",
                                          style: TextStyle(
                                            color: Colors.black54,
                                          ),
                                        ),
                                      ),
                              ),
                            ),
                          ),
                        ],
                      );
                    }
                  },
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

class ShowUp extends StatefulWidget {
  final Widget child;
  final int delay;

  const ShowUp({super.key, required this.child, required this.delay});

  @override
  ShowUpState createState() => ShowUpState();
}

class ShowUpState extends State<ShowUp> with TickerProviderStateMixin {
  late AnimationController _animController;
  late Animation<Offset> _animOffset;

  @override
  void initState() {
    super.initState();

    _animController = AnimationController(
        vsync: this, duration: const Duration(milliseconds: 500));
    final curve =
        CurvedAnimation(curve: Curves.decelerate, parent: _animController);
    _animOffset =
        Tween<Offset>(begin: const Offset(0.0, 0.35), end: Offset.zero)
            .animate(curve);

    Timer(Duration(milliseconds: widget.delay), () {
      _animController.forward();
    });
  }

  @override
  void dispose() {
    super.dispose();
    _animController.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return FadeTransition(
      opacity: _animController,
      child: SlideTransition(
        position: _animOffset,
        child: widget.child,
      ),
    );
  }
}
